@@ -286,7 +286,11 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     connect(bg, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), this, &KfindTabWidget::fixLayout);
     connect(sizeBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &KfindTabWidget::slotSizeBoxChanged);
     connect(timeBox, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KfindTabWidget::slotUpdateDateLabelsForNumber);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(betweenType, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &KfindTabWidget::slotUpdateDateLabelsForType);
+#else
+    connect(betweenType, static_cast<void (KComboBox::*)(int, const QString &)>(&KComboBox::currentIndexChanged), this, &KfindTabWidget::slotUpdateDateLabelsForType);
+#endif
     connect(sizeEdit, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &KfindTabWidget::slotUpdateByteComboBox);
 
     // ************ Page Three
@@ -545,6 +549,7 @@ void KfindTabWidget::loadHistory()
 
 void KfindTabWidget::slotEditRegExp()
 {
+#if 0
     if (!regExpDialog) {
         regExpDialog = KServiceTypeTrader::createInstanceFromQuery<QDialog>(QStringLiteral("KRegExpEditor/KRegExpEditor"), QString(), this);
     }
@@ -558,6 +563,7 @@ void KfindTabWidget::slotEditRegExp()
     if (regExpDialog->exec()) {
         textEdit->setText(iface->regExp());
     }
+#endif
 }
 
 void KfindTabWidget::setFocus()
@@ -714,10 +720,14 @@ void KfindTabWidget::setQuery(KQuery *query)
         if (rb[0]->isChecked()) { // Between dates
             const QDate &from = fromDate->date();
             const QDate &to = toDate->date();
-
             // do not generate negative numbers .. find doesn't handle that
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             time_t time1 = epoch.secsTo(QDateTime(from));
             time_t time2 = epoch.secsTo(QDateTime(to.addDays(1))) - 1; // Include the last day
+#else
+            time_t time1 = epoch.secsTo(QDateTime(from.startOfDay()));
+            time_t time2 = epoch.secsTo(QDateTime(to.addDays(1).startOfDay())) - 1; // Include the last day
+#endif
 
             query->setTimeRange(time1, time2);
         } else {
